#!/bin/sh
#
# Component: archive
#
# Description:
#  OBSOLETE [7.0]
#
#  applys changes in a PbR file to an Object.
#
# Usage:
#   applychanges.sh -n -p <PbR> { -o <object> | -d <study directory> }
#
#    -n                   : Do not lock (the same as legacy -nolock)
#    -p <PbR>             : Full path to the PbR file having the changes to be applied
#    -o <object>          : Full path to the object file the changes to be applied to
#    -d <study directory> : Full path to study directory to apply changes to all objects in the directory
#
# Legacy Usage: 
#   applychanges.sh <object> <PbR> [-nolock]
#
#    object :  Absolute pathname of the object file
#    PbR    :  Absolute pathname of the PbR file to be applied
#	 -nolock:  if present no locking is done (should be used when called directly from put.sh)
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

# if applychanges.sh is called directly:
# run as a task instead
if [ `basename $0` = "applychanges.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi

LOGGER="/usr/bin/logger"
TAG="applychanges[$$]"

INPUT_PARAMS=""
pbrFile=""
objectFile=""
studyDir=""
noLock="false"

while getopts 'p:o:d:n' OPT; do
	case $OPT in
	p) INPUT_PARAMS="$INPUT_PARAMS -p \"$OPTARG\"" ; pbrFile="$OPTARG" ;;
	o) INPUT_PARAMS="$INPUT_PARAMS -o \"$OPTARG\"" ; objectFile="$OPTARG" ;;
	d) INPUT_PARAMS="$INPUT_PARAMS -d \"$OPTARG\"" ; studyDir="$OPTARG" ;;
	n) INPUT_PARAMS="$INPUT_PARAMS -n" ; noLock="true" ;;
	*) errMsg="Invalid_Parameter:$OPT" ;;
	esac
done

if [ -z "$pbrFile" ] ; then
	# checking for legacy arguments
	shift $(( $OPTIND - 1 ))

	objectFile="$1"
	pbrFile="$2"
	INPUT_PARAMS="$INPUT_PARAMS -p \"$pbrFile\" -o \"$objectFile\""
	if [ "$3" == "-nolock" ] ; then
		noLock="true"
		INPUT_PARAMS="$INPUT_PARAMS -n"
	fi
fi

# include nettask.shi for checking if the device is temporary down
. $TASKD_HOME/nettask.shi

# override getPeer_() of nettask.shi
getPeer_()
{
	echo "@Archive @Archive-PUT"
}

run_()
{
	argError=""
	[ -z "$objectFile" -a -z "$studyDir" ] && argError="Neither object file nor study directory was provided"
	[ -n "$objectFile" -a -n "$studyDir" ] && argError="Both object file and study directory was provided"
	[ -z "$pbrFile" ] && argError="No PbR file was provided"
	
	if [ -n "$argError" ] ; then
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "Missing or invalid argument(s): $argError"
		return 125
	fi


	$TASKD_HOME/runjavacmd -c "0 archive.ApplyChanges $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
	ERR=$?

	exit $ERR
}


# override print_
print_()
{
	$TASKD_HOME/runjavacmd -c "print archive.ApplyChanges $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
}

#
# Print value to be displayed on the WEB GUI
#
get_display_name_()
{
	echo "Applies soft edit changes to object in EP archive" 
}

#
# Print resources used by the task 
#
get_resources_()
{
	echo "System.NET.@Archive.PUT"
}

#
# Print property value
#
get_property_()
{
	if [ "$PROPERTY" = "1PPE" ] ; then
		echo -n "@Archive" 
		return 0
	fi

	get_def_property_
}
