#!/bin/sh
#
# Component: cases
#
# OBSOLETE: cases.DcautoForward should be used instead
#
# Description:
#   Forwards a single DICOM object file to all servers noted as autoforward
#   including dotcom servers and archive
#
# Usage:
#   dcautofwd.sh -f <file> -s <study> -H <host>
#      file    : short file name of the DICOM object
#      study   : Study Instance UID of the DICOM object
#      host    : ID of the device from where the DICOM object was received
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

# if dcautofwd.sh is called directly:
# run as a task instead
if [ `basename $0` = "dcautofwd.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi

ErrMsg=""

# Command line arguments
File=""
Study=""
Host=""
INPUT_PARAMS=""

while getopts 'f:s:H:' OPT; do
	case $OPT in
	f) File="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -f \"$OPTARG\"" ;;
	s) Study="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -s \"$OPTARG\""  ;;
	H) Host="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -H \"$OPTARG\""  ;;
	*) ErrMsg="Invalid_Parameter:$OPT" ;;
	esac
done

Pid=$$
Date=`date`

LOGGER="/usr/bin/logger"
TAG="dcautofwd.sh[$$]"

run_() # override run_ method
{
	$LOGGER -p $LOG_FACILITY.debug -t "$TAG" "Auto Forward $Study $File $Host"
	$TASKD_HOME/runjavacmd -c "0 cases.DcAutoForward $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
	ERR=$?

	exit $ERR
}


# Override default cleanup_
# release reference counter
cleanup_()
{
	$TASKD_HOME/runjavacmd -c "cleanup cases.DcAutoForward $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
}

# override print_
print_()
{
	$TASKD_HOME/runjavacmd -c "print cases.DcAutoForward $INPUT_PARAMS" -p "$JAVA_SERVER_PORT"
}


get_watson_message_()
{
	[ -z "$DR_WATSON_ID" ] && DR_WATSON_ID="autofwd.$Study"
	[ -z "$DR_WATSON_MESSAGE" ] && DR_WATSON_MESSAGE="Starting autoforward study $STUDY"

	if [ "$RUN_RESULT" -gt 124 ] ; then
		WATSON_MESSAGE_ID="$DR_WATSON_ID.failed"
		WATSON_MESSAGE_TEXT="FAILED: $DR_WATSON_MESSAGE"
		return
	fi

	if [ "$RUN_RESULT" -ne 0 -a "$RETRY_NUM" -gt 0 -a $(( $RETRY_NUM % 10)) -eq 0 ] ; then
		WATSON_MESSAGE_TEXT="ERROR: $DR_WATSON_MESSAGE [Retry #$RETRY_NUM]"
		WATSON_MESSAGE_ID="$DR_WATSON_ID.$RETRY_NUM"
	fi
} # get_watson_message_()
