var timeLines = new Array();
var timeLineMap = new Array();

function refreshTLs() {
	for ( var i = 0; i < timeLines.length; i++ ) {
		timeLines[ i ].render();
	}
}

function addResizeEvent( func ) {
	var oldresize = window.onresize;
	if ( typeof oldresize != 'function' ) {
		window.onresize = func;
	}
	else {
		window.onresize = function() {
			oldresize();
			func();
		};
	}
};

function getBoxHeight() {

	var $inspector = $( "<div>" ).css( 'display', 'none' ).addClass( "TLDivCommon" );
	$( "body" ).append( $inspector ); // add to DOM, in order to read the CSS property
	try {
		return $inspector.height();
	}
	finally {
		$inspector.remove(); // and remove from DOM
	}
};

function Timeline( root ) {
	timeLines.push( this );
	timeLineMap[ root ] = this;
	addResizeEvent( refreshTLs );
	addLoadEvent( refreshTLs );
	this.root = root;
	this.rootElement = document.getElementById( root );
	this.rootElement.style.position = "relative";
	this.minDate = new Date().getTime();
	this.maxDate = this.minDate;
	this.range = 0;
	this.minRange = 1000 * 86400 * 7;
	this.mode = 'simple'; // simple vs. time modes

	// calculate boxHeight
	this.boxheight = getBoxHeight() + 8; // the inner size + 8 for top and bottom
	// border+padding
	// detect height/width from css rules

	this.width = 200;
	this.height = 600; // render will update it from container's height

	this.n = 0;
	this.dirty = false;

	this.objects = new Array();

	this.sortByDate = function( a, b ) {
		return b.date - a.date;
	};

	this.setDivStyle = function( div ) {
		//div.style.height = ( this.boxheight - 8 ) + 'px';
		div.style.position = 'absolute';
		div.style.overflow = 'hidden';
		div.style.textOverflow = 'ellipsis';
		div.style.left = '20px';
	};

	this.setObjects = function( objs ) {
		this.objects = objs;
		this.dirty = true;
		this.render();
	};

	this.clearObjects = function() {
		while ( this.objects.pop() ) {}
		this.dirty = true;
	};

	this.clear = function() {
		while ( this.rootElement.hasChildNodes() ) {
			this.rootElement.removeChild( this.rootElement.firstChild );
		}
	};

	// calc range, min, max
	this.calcRange = function() {
		var o;
		o = this.objects[ this.n - 1 ];
		this.minDate = o.date.getTime();
		o = this.objects[ 0 ];
		this.maxDate = Math.max( new Date().getTime(), o.date.getTime() );

		this.range = this.maxDate - this.minDate;

		if ( this.range < this.minRange ) {
			this.range = this.minRange;
		}
	};

	// the Math
	this.calcTop = function( nObj, dDate ) {
		return Math.floor( nObj * this.boxheight + 1 + ( this.height - this.n * ( this.boxheight + 1 ) ) * ( ( this.maxDate - dDate + 0.0 ) / this.range ) );
	};

	this.render = function() {
		this.clear();
		if ( this.dirty ) {
			// should be sorted by date descending -- actually sort??
			this.objects.sort( this.sortByDate );
			this.dirty = false;
		}
		// first pass: find smallest/largets date

		this.n = this.objects.length;
		this.height = this.rootElement.clientHeight;
		// element's height...

		this.calcRange();

		// tickmarks should be drawn between object i and i+1 (!)
		var dPrev = this.maxDate;
		var lastTickPos = this.calcTop( 0, dPrev );

		for ( var o = 0; o <= this.objects.length; o++ ) {
			var obj = "";
			var dDate;
			if ( o < this.objects.length ) {
				obj = this.objects[ o ];
				dDate = obj.date;
			}
			else {
				dDate = new Date( this.maxDate - this.range - 1 );
			}
			var dCur = dDate.getTime();

			if ( dPrev != null && dPrev >= dCur && this.mode != 'simple' ) {
				// show tickmarks for day, month or year

				var dIter = dPrev;

				while ( 1 ) {

					var y, y0, m, m0, d, d0;
					var dd = new Date( dIter );
					y = y0 = dd.getFullYear();
					m = m0 = dd.getMonth();
					d = d0 = dd.getDate();
					var mode;

					// step one unit
					if ( this.range < 1000 * 86400 * 10 ) {
						var yesterday = new Date( new Date( y, m, d ).getTime() - 1000 * 86400 );
						y = yesterday.getFullYear();
						m = yesterday.getMonth();
						d = yesterday.getDate();
						mode = 'day';
					}
					else if ( this.range < 1000 * 86400 * 3650 ) {
						d0 = 1; // marker on the 1st
						m--;
						if ( m < 0 ) {
							m = 11;
							y--;
						}
						mode = 'month';
					}
					else {
						d0 = 1;
						m0 = 0; // marker on Jan 1st
						y--;
						m = 0;
						mode = 'year';
					}

					// if the current iterator was not on a marker, set it to a marker
					// otherwise move one unit

					var dIterMark = new Date( y0, m0, d0 ).getTime();
					if ( dIterMark < dIter ) {
						y = y0;
						m = m0;
						d = d0;
					}
					var dIterOld = dIter;
					dIter = new Date( y, m, d ).getTime();

					// if (o<=this.objects.length) { alert (dIter+' : ' + dCur); }
					if ( o < this.objects.length ) {
						if ( dIter < dCur )
							break;
					}
					else if ( dIter < dCur )
						dIter = dCur;

					var t = lastTickPos;
					var tickDiv = document.createElement( 'div' );
					var b = this.calcTop( o, dIter );
					lastTickPos = b;
					tickDiv.style.top = t + 'px';
					tickDiv.style.position = 'absolute';
					tickDiv.style.margin = '0 0 0 0';
					tickDiv.style.padding = '0 0 0 0';
					tickDiv.style.height = Math.max( 0, b - t - 1 ) + 'px';
					tickDiv.style.border = 'none 0px ';
					tickDiv.style.borderBottom = 'black 1px solid';
					tickDiv.style.left = '4px';
					tickDiv.style.width = '8px';
					tickDiv.style.background = '#303030';

					var s;
					var dIterDate = new Date( dIter );

					if ( m == 0 && d == 1 ) {
						tickDiv.style.borderBottom = '#FFFFFF 1px solid';
					}
					else if ( d == 1 ) {
						tickDiv.style.borderBottom = '#808080 1px solid';
					}
					else {
						tickDiv.style.borderBottom = '#000000 1px solid';
					}

					if ( mode == 'day' )
						s = ( dIterDate.getMonth() + 101 + '' ).substr( 1 ) + '/' + dIterDate.getDate();
					else
						s = dIterDate.getFullYear() + '/' + ( dIterDate.getMonth() + 101 + '' ).substr( 1 );

					// tickDiv.style.border=bs;
					// tickDiv.title = s;
					this.rootElement.appendChild( tickDiv );

					if ( dIter <= dCur )
						break; // break out for last item

				}

			}

			if ( o == this.objects.length )
				break;

			dPrev = dCur;

			// find, or create the div
			if ( obj.id ) {
				var div0 = document.getElementById( obj.id );

				if ( div0 != null ) {
					if ( div0.parentNode != this.root && div0.parentNode != null ) {
						throw ( "Timeline: Element '" + obj.id + "' has wrong parent" );
					}
					if ( obj.div != null && obj.div != div0 ) {
						throw ( "Timeline: stored div '" + obj.div + "' doesn't match" );
					}
					obj.div = div0;
				}
			}
			if ( obj.div == null ) {
				// we'll create the document;
				obj.div = document.createElement( 'div' );
				if ( obj.style != null ) {
					for ( var s in obj.style ) {
						obj.div.style[ s ] = obj.style[ s ];
					}
				}
				if ( obj.className != null ) {
					obj.div.className = obj.className;
				}
				this.setDivStyle( obj.div );
			}
			var top = this.calcTop( o, dCur );
			if ( this.mode == 'simple' )
				top = o * this.boxheight + 1;
			obj.div.style.top = top + 'px';

			if ( obj.stem == null ) {
				obj.stem = document.createElement( 'div' );
				obj.stem.style.position = 'absolute';
				obj.stem.style.width = '29px';
				obj.stem.style.height = '3px';
				obj.stem.style.left = '5px';
				obj.stem.style.borderTop = 'black 2px solid';
				obj.stem.title = dDate.toDateString();
			}
			// add the stem
			obj.stem.style.top = top + Math.floor( this.boxheight / 2 ) + 'px';
			if ( obj.stem.parentNode != this.rootElement ) {
				this.rootElement.appendChild( obj.stem );
			}
			// append if needed
			if ( obj.div.parentNode != this.rootElement ) {
				this.rootElement.appendChild( obj.div );
			}
		}
		if ( isIE ) {
			// ensure enclosing DIV has enough height to contain all the boxes (IE seems to be too stupid to do it properly)
			var minHeight = this.objects.length * ( this.boxheight ) + 2;
			$( this.rootElement ).height( "100%" );
			if ( $( this.rootElement ).height() < minHeight ) {
				$( this.rootElement ).height( minHeight );
			}
		}
		if ( this.mode == 'simple' ) {
			// one single thick line
			var tickDiv = document.createElement( 'div' );

			with ( tickDiv.style ) {
				top = '0px';
				position = 'absolute';
				margin = '0 0 0 0';
				padding = '0 0 0 0';
				height = "100%";//this.height + 'px';
				border = 'none 0px ';
				borderBottom = 'black 1px solid';
				left = '4px';
				width = '8px';
				background = '#303030';
			}
			this.rootElement.appendChild( tickDiv );
		}
	};

};
