#!/bin/sh
#
# Component: cases
#
# Purpose:
#     Handles STUDYDIR released events
#
# Usage:
#    onStudydirReleased.sh -t <type> -e <event> -i <id>
#
#    -t type  : Object type to be released. It will always be "STUDYDIR"
#    -e event : Event triggered runiing this script. It will always be "RELASED"
#    -i id    : Identifies the studydb object (=Study Instance UID)
#
# Description:
#     Will be called when a STUDYDIR reference counter is released.
# The study directory with all content will be removed.
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

# onStudydirReleased.sh can be called directly:
# run as a task instead
if [ `basename $0` = "onStudydirReleased.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi

LOGGER="/usr/bin/logger"
TAG="onStudydirReleased[$$]"

study=""
type=""
event=""
errMsg=""
INPUT_PARAMS=""

while getopts 'e:t:i:' OPT; do
	case $OPT in
	e) event="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -e \"$OPTARG\"" ;;
	t) type="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -t \"$OPTARG\"" ;;
	i) study="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -i \"$OPTARG\"" ;;
	*) errMsg="Invalid_Parameter:$OPT" ;;
	esac
done

[ -f "$CONF/taskd.rc" ] && . $CONF/taskd.rc

command="${CASES_HOME#$HOME/component/}.OnStudydirReleased $INPUT_PARAMS"

run_()
{
	$TASKD_HOME/runjavacmd -c "0 $command" -p $JAVA_SERVER_PORT
	ERR=$?
	
	exit $ERR
}

cleanup_()
{
	$TASKD_HOME/runjavacmd -c "cleanup $command" -p $JAVA_SERVER_PORT
	ERR=$?
	
	exit $ERR
}

print_()
{
	$TASKD_HOME/runjavacmd -c "print $command" -p $JAVA_SERVER_PORT
	ERR=$?
	
	exit $ERR
}
