#/bin/sh
#
# Component: checkintegrity
#
# Description:
#      Checks if a study/object exists in the configured external archive.
#
# Usage:
#      checkExternalArchive.sh <study> <object>
#
# Exit Codes:
#
#      0          - OK, the study/object exists in the external archive
#      1          - FAILED, the study/object does not exist in the external archive 
#      2 or above - ERROR, an error occured while checking study/object
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

study="$1"
object="$2"

if [ -z "$study" -o -z "$object" ] ; then
	echo "Missing argument(s): <study> <object>" >&2
	exit 2
fi

ExternalRetrieve=""
[ -f "$ARCHIVE_VAR/archive.cfg" ] && . $ARCHIVE_VAR/archive.cfg

if [ -z "$ExternalRetrieve" ] ; then
	echo "No external archive defined" >&2
	exit 2
fi



if [ ! -f "$TMP/extchk.$study" ] ; then
	cat <<-ENDOFDMP > $TMP/extchk.$$
		(0008,0052) CS [IMAGE]                #   6, 1 QueryRetrieveLevel
		(0020,000d) UI [$study]               #   0, 0 StudyInstanceUID
		(0008,0018) UI (no value available)   #  50, 1 SOPInstanceUID
	ENDOFDMP

	$QR_HOME/find.sh -h $ExternalRetrieve -f $TMP/extchk.$$ > $TMP/extchkout.$$
	if [ $? -ne 0 ] ; then
		echo "find.sh returned error" >&2
		exit 2
	fi

	sed -n 's;^(0008,0018) UI \[\(.*\)\].*$;\1;p' $TMP/extchkout.$$ > $TMP/extchk.$study

	rm $TMP/extchkout.$$
	rm $TMP/extchk.$$
fi


objuid=`sed 's;^[^.]*\.;;' <<<"$object"`

if ! grep -q "\<$objuid\>" $TMP/extchk.$study; then
	echo FAILED
	exit 1
fi

echo OK
exit 0

