#!/bin/sh
#
# Component: checkintegrity
#
# Description:
#      Checks if all study in the data repository has a study table entry.
#      If -f option is turned on, also tries to fix detected inconsistencies in the following way:
#         - Fixes Deleted flag mismatches between storestate.rec and database entry by updating the database entry
#         - Schedules StorescpReg/Dcreg tasks for unindexed objects.
#         - For empty study directories having no study table entries a Study table entry with empty values will be created.
#      Detected and fixed inconsistencies will be logged to info.log
#
# Usage:
#      dcfixall.sh [-f]
#
#       -f                   : fix detected inconsistencies
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

DOFIX=""
while getopts 'f' OPT; do
	case $OPT in
		f) DOFIX="-f" ;;
		*) echo "Invalid option: $OPT" ; exit 1 ;;
	esac
done

$TASKD_HOME/runjavacmd -c "0 imagemed.checkintegrity.DcFixall $DOFIX" -p $JAVA_SERVER_PORT
