<%--
 * Component: iface
 *
 * Description:
 *    Allow opening a study using Accession Number(s)
 * 
 * If there are more than one studies for an accession number, an error response will be returned.
 *
 * @params:
 *
 *   ACCN   accession number of the study to be opened.
 *          More than one accession number can be specified separated by semicolon (;)
 *   SYUI   study instance UID of the study to be opened
 *          More than one study can be specified separated by semicolon (;)
 *   VCID   viewer open context id. This contains all the data (studies, if
 *          needed study list and prev next context).
 *
 *   cMultipleMode    how to handle multiple matches on accession numbers
 *                    possible values are
 *                    normal (default):  return an error message
 *                    open            :  open all matching studies in the viewer
 *                    list            :  popup worklist with matching studies
 *
 *   cUser    user id
 *   cPasswd  password
 *
 *
 *   For internal use only 
 *   cAppend          true indicates to open studies in existing viewer session by keeping other studies open
 *   cViewSessionID   viewer session the studies to be appened to. 
 *   cOpenMan         true indicates to allow opening empty study lists and non-existing studies
 *                    and to bring up Manager Window in the viewer
 *
--%><%@page import="com.erad.pacs.services.usermanager.client.Session"%>
<%@page import="com.erad.pacs.common.libs.ViewerOpenContext"
%><%@page import="com.erad.pacs.common.libs.SessionStore"
%><%@page import="com.erad.pacs.common.libs.RequestInfo"
%><%@page import="com.erad.pacs.services.usermanager.tomcat.Sessita"
%><%@page import="java.util.Iterator"
%><%@page import="java.util.Vector"
%><%@
	page import="com.erad.pacs.app.broker.table.internals.*,com.erad.pacs.app.broker.table.internals.imtables.*, com.erad.pacs.app.broker.table.internals.action.*,
			com.erad.pacs.app.broker.table.internals.lists.*, com.erad.pacs.app.broker.table.internals.imtables.DBLDSWrapperSqlResultImpl.IncrementalContextImpl,
			imagemed.util.Helper, imagemed.jsputil.*, imagemed.exception.*"
	
%><%!

	static final int MULTIPLE_MODE_NORMAL = 0;
	static final int MULTIPLE_MODE_OPEN = 1;
	static final int MULTIPLE_MODE_LIST = 2;

%><%
	Sessita sessita = Sessita.Create( request, response );
	Session sess = sessita.getSession();

	String parAccno = request.getParameter( "ACCN" );
	String parStudies = request.getParameter( "SYUI" );
	String parPatient = request.getParameter( "PAID" );
	String parMultipleMode = request.getParameter( "cMultipleMode" );
	
	// With viewer context id we shortcut this whole thing, because the context
	// contains the data. Here we do a check, that the context is valid.
	String parViewerContextId = request.getParameter( "VCID" );
	if (null != parViewerContextId) {
		SessionStore store = SessionStore.getInstance( sess );
		ViewerOpenContext openContext = store.getViewerOpenContext();
		if ( null != openContext ) {
			if ( openContext.getContextId().equals( parViewerContextId ) ) {
				String url = GetpbsToolbox.getURLforGetpbs();
				response.sendRedirect( url + "?cViewerContextId=" + openContext.getContextId(  ) );
				//IfaceToolbox.loginAndRedirect( request.getParameterMap(), new RequestInfo(request), loc, response );
			}
			else {
				out.println("ERROR: Wrong viewer context id!");
				return;
			}
		}
		else {
			out.println("ERROR: Invalid viewer context id!");
			return;
		}
	}
	
	boolean isAppend = "true".equals( request.getParameter( "cAppend" ) );
	String viewSessionID =  request.getParameter( "cViewSessionID" );
	boolean needOpenMan = "true".equals( request.getParameter( "cOpenMan" ) );

	String sessionID =  request.getParameter( "sessionid" );

	int multipleMode = MULTIPLE_MODE_NORMAL;
	if ( "list".equals( parMultipleMode ) ) {
		multipleMode = MULTIPLE_MODE_LIST;
	}
	else if ( "open".equals( parMultipleMode ) ) {
		multipleMode = MULTIPLE_MODE_OPEN;
	}
	// FIXME, if needed
	// is.sessionVariables.setProperty("httpIface", "true");

	try {
		StudyFinder sf = new StudyFinder( sess, true, false, parAccno, parStudies, parPatient );
		Vector<String> studySet = sf.collectStudyList( sess, multipleMode != MULTIPLE_MODE_OPEN, needOpenMan ); 

		if ( studySet.isEmpty() && ! needOpenMan ) {
			IfaceToolbox.printError( sess, response.getWriter(), "No study found" );
			return;
		}

		StringBuffer passStudies = new StringBuffer();
		for ( Iterator<String> i = studySet.iterator(); i.hasNext(); ) {
			passStudies.append( "&cGr=" + i.next() );
		}

		if ( isAppend ) {
			passStudies.append( "&Append=true" );
		}
		if ( viewSessionID != null ) {
			passStudies.append( "&ViewSessionID=" + Helper.URLEncodeUTF8( viewSessionID ) );
		}
		
		if ( needOpenMan ) {
			StringBuilder openManParams = new StringBuilder( 256 );
			if ( parAccno != null ) {
				openManParams.append( "&ACCN=" ).append( Helper.URLEncodeUTF8( parAccno ) );
			}
			if ( parStudies != null ) {
				openManParams.append( "&SYUI=" ).append( Helper.URLEncodeUTF8( parStudies ) );
			}
			if ( parPatient != null ) {
				openManParams.append( "&PAID=" ).append( Helper.URLEncodeUTF8( parPatient ) );
			}

			passStudies.append( "&cOpenMan=" + Helper.URLEncodeUTF8( openManParams.substring( 1 ) ) );
		}
		
		String url = GetpbsToolbox.getURLforGetpbs( );
		String loc = new RequestInfo(request).getHttpxHost(  ) + url + "?" + passStudies.substring( 1 );
		if( sessionID != null ) {
			loc += "&sessionid=" + sessionID;
		}
		IfaceToolbox.loginAndRedirect( request.getParameterMap(), new RequestInfo(request), loc, response );

	}
	catch ( IMMultipleMatchException mmex ) {
		if ( multipleMode == MULTIPLE_MODE_LIST ) {
			// Popup worklist
			StringBuffer redirectParams = new StringBuffer();
			if ( sess.getSessionId(  ) != null ) {
				redirectParams.append( "&sessionid=" ).append( Helper.URLEncodeUTF8( sess.getSessionId(  ) ) );
			}
			if ( parAccno != null ) {
				redirectParams.append( "&qf_ACCN=" ).append( Helper.URLEncodeUTF8( parAccno ) );
			}
			if ( parStudies != null ) {
				redirectParams.append( "&qf_SYUI=" ).append( Helper.URLEncodeUTF8( parStudies ) );
			}
			if ( parPatient != null ) {
				redirectParams.append( "&qf_PAID=" ).append( Helper.URLEncodeUTF8( parPatient ) );
			}

			RequestInfo requestInfo = new RequestInfo(request);
			IfaceToolbox.loginAndRedirect( request.getParameterMap(), requestInfo, requestInfo.getHttpxHost(  ) + "/cases/index.jsp?" + redirectParams.substring( 1 ), response );
			return;
		}

		response.setContentType( "text/plain" );
		out.println( mmex.getFormattedMessage() );
	}
	catch ( IMIfaceException ex ) {
		response.setContentType( "text/plain" );
		out.println( ex.getFormattedMessage() );
	}
	
	if ( true ) {
		// To avoid sending any other character on the connection after redirect
		return;
	}
%>